@@ -7,8 +7,7 @@ from . import cucumber_json
 from . import generation
 from . import reporting
 from . import gherkin_terminal_reporter
-
-from .fixtures import *
+from .utils import CONFIG_STACK
 
 
 def pytest_addhooks(pluginmanager):
@@ -32,20 +31,31 @@ def trace():
 
 def pytest_addoption(parser):
     """Add pytest-bdd options."""
+    add_bdd_ini(parser)
     cucumber_json.add_options(parser)
     generation.add_options(parser)
     gherkin_terminal_reporter.add_options(parser)
 
 
+def add_bdd_ini(parser):
+    parser.addini('bdd_features_base_dir',
+                  'Base features directory.')
+    parser.addini('bdd_strict_gherkin',
+                  'Parse features to be strict gherkin.',
+                  type='bool', default=True)
+
+
 @pytest.mark.trylast
 def pytest_configure(config):
     """Configure all subplugins."""
+    CONFIG_STACK.append(config)
     cucumber_json.configure(config)
     gherkin_terminal_reporter.configure(config)
 
 
 def pytest_unconfigure(config):
     """Unconfigure all subplugins."""
+    CONFIG_STACK.pop()
     cucumber_json.unconfigure(config)
 
 
