@@ -23,7 +23,6 @@ except ImportError:
 import six
 
 from . import exceptions
-from . import fixtures
 from .feature import (
     Feature,
     force_encode,
@@ -39,7 +38,7 @@ from .steps import (
     recreate_function,
 )
 from .types import GIVEN
-from .utils import get_args, get_fixture_value
+from .utils import CONFIG_STACK, get_args
 
 if six.PY3:  # pragma: no cover
     import runpy
@@ -50,8 +49,8 @@ if six.PY3:  # pragma: no cover
         init_globals.update(result)
 
 
-PYTHON_REPLACE_REGEX = re.compile("\W")
-ALPHA_REGEX = re.compile("^\d+_*")
+PYTHON_REPLACE_REGEX = re.compile(r"\W")
+ALPHA_REGEX = re.compile(r"^\d+_*")
 
 
 def find_argumented_step_fixture_name(name, type_, fixturemanager, request=None):
@@ -71,7 +70,7 @@ def find_argumented_step_fixture_name(name, type_, fixturemanager, request=None)
                 parser_name = get_step_fixture_name(parser.name, type_)
                 if request:
                     try:
-                        get_fixture_value(request, parser_name)
+                        request.getfixturevalue(parser_name)
                     except pytest_fixtures.FixtureLookupError:
                         continue
                 return parser_name
@@ -89,12 +88,12 @@ def _find_step_function(request, step, scenario, encoding):
     """
     name = step.name
     try:
-        return get_fixture_value(request, get_step_fixture_name(name, step.type, encoding))
+        return request.getfixturevalue(get_step_fixture_name(name, step.type, encoding))
     except pytest_fixtures.FixtureLookupError:
         try:
             name = find_argumented_step_fixture_name(name, step.type, request._fixturemanager, request)
             if name:
-                return get_fixture_value(request, name)
+                return request.getfixturevalue(name)
             raise
         except pytest_fixtures.FixtureLookupError:
             raise exceptions.StepDefinitionNotFoundError(
@@ -129,7 +128,7 @@ def _execute_step_function(request, scenario, step, step_func):
     kw["step_func_args"] = {}
     try:
         # Get the step argument values.
-        kwargs = dict((arg, get_fixture_value(request, arg)) for arg in get_args(step_func))
+        kwargs = dict((arg, request.getfixturevalue(arg)) for arg in get_args(step_func))
         kw["step_func_args"] = kwargs
 
         request.config.hook.pytest_bdd_before_step_call(**kw)
@@ -189,6 +188,7 @@ def _execute_scenario(feature, scenario, request, encoding):
                     step=step,
                     step_func=step_func,
                     exception=exception,
+                    step_func_args=dict((arg, request.getfixturevalue(arg)) for arg in get_args(step_func)),
                 )
                 raise
 
@@ -204,31 +204,6 @@ def _execute_scenario(feature, scenario, request, encoding):
 FakeRequest = collections.namedtuple("FakeRequest", ["module"])
 
 
-def get_fixture(caller_module, fixture, path=None):
-    """Get first conftest module from given one."""
-    def call_fixture(function):
-        args = []
-        if "request" in get_args(function):
-            args = [FakeRequest(module=caller_module)]
-        return function(*args)
-
-    if path is None:
-        if hasattr(caller_module, fixture):
-            return call_fixture(getattr(caller_module, fixture))
-        path = os.path.dirname(caller_module.__file__)
-
-    if os.path.exists(os.path.join(path, "__init__.py")):
-        file_path = os.path.join(path, "conftest.py")
-        if os.path.exists(file_path):
-            globs = {}
-            execfile(file_path, globs)
-            if fixture in globs:
-                return call_fixture(globs[fixture])
-    else:
-        return call_fixture(getattr(fixtures, fixture))
-    return get_fixture(caller_module, fixture, path=os.path.dirname(path))
-
-
 def _get_scenario_decorator(feature, feature_name, scenario, scenario_name, caller_module, caller_function, encoding):
     """Get scenario decorator."""
     g = locals()
@@ -272,7 +247,8 @@ def _get_scenario_decorator(feature, feature_name, scenario, scenario_name, call
                 _scenario = pytest.mark.parametrize(*param_set)(_scenario)
 
         for tag in scenario.tags.union(feature.tags):
-            pytest.config.hook.pytest_bdd_apply_tag(tag=tag, function=_scenario)
+            config = CONFIG_STACK[-1]
+            config.hook.pytest_bdd_apply_tag(tag=tag, function=_scenario)
 
         _scenario.__doc__ = "{feature_name}: {scenario_name}".format(
             feature_name=feature_name, scenario_name=scenario_name)
@@ -284,7 +260,7 @@ def _get_scenario_decorator(feature, feature_name, scenario, scenario_name, call
 
 
 def scenario(feature_name, scenario_name, encoding="utf-8", example_converters=None,
-             caller_module=None, caller_function=None):
+             caller_module=None, caller_function=None, features_base_dir=None, strict_gherkin=None):
     """Scenario decorator.
 
     :param str feature_name: Feature file name. Absolute or relative to the configured feature base path.
@@ -298,9 +274,11 @@ def scenario(feature_name, scenario_name, encoding="utf-8", example_converters=N
     caller_function = caller_function or get_caller_function()
 
     # Get the feature
-    base_path = get_fixture(caller_module, "pytestbdd_feature_base_dir")
-    strict_gherkin = get_fixture(caller_module, "pytestbdd_strict_gherkin")
-    feature = Feature.get_feature(base_path, feature_name, encoding=encoding, strict_gherkin=strict_gherkin)
+    if features_base_dir is None:
+        features_base_dir = get_features_base_dir(caller_module)
+    if strict_gherkin is None:
+        strict_gherkin = get_strict_gherkin()
+    feature = Feature.get_feature(features_base_dir, feature_name, encoding=encoding, strict_gherkin=strict_gherkin)
 
     # Get the sc_enario
     try:
@@ -330,6 +308,26 @@ def scenario(feature_name, scenario_name, encoding="utf-8", example_converters=N
     )
 
 
+def get_features_base_dir(caller_module):
+    default_base_dir = os.path.dirname(caller_module.__file__)
+    return get_from_ini('bdd_features_base_dir', default_base_dir)
+
+
+def get_from_ini(key, default):
+    """Get value from ini config. Return default if value has not been set.
+
+    Use if the default value is dynamic. Otherwise set default on addini call.
+    """
+    config = CONFIG_STACK[-1]
+    value = config.getini(key)
+    return value if value != '' else default
+
+
+def get_strict_gherkin():
+    config = CONFIG_STACK[-1]
+    return config.getini('bdd_strict_gherkin')
+
+
 def make_python_name(string):
     """Make python attribute name out of a given string."""
     string = re.sub(PYTHON_REPLACE_REGEX, "", string.replace(" ", "_"))
@@ -357,12 +355,19 @@ def scenarios(*feature_paths, **kwargs):
     """
     frame = inspect.stack()[1]
     module = inspect.getmodule(frame[0])
-    base_path = get_fixture(module, "pytestbdd_feature_base_dir")
-    strict_gherkin = get_fixture(module, "pytestbdd_strict_gherkin")
+
+    features_base_dir = kwargs.get('features_base_dir')
+    if features_base_dir is None:
+        features_base_dir = get_features_base_dir(module)
+
+    strict_gherkin = kwargs.get('strict_gherkin')
+    if strict_gherkin is None:
+        strict_gherkin = get_strict_gherkin()
+
     abs_feature_paths = []
     for path in feature_paths:
         if not os.path.isabs(path):
-            path = os.path.abspath(os.path.join(base_path, path))
+            path = os.path.abspath(os.path.join(features_base_dir, path))
         abs_feature_paths.append(path)
     found = False
 
